define({ "api": [
  {
    "type": "GET",
    "url": "plugin",
    "title": "getBindInfo",
    "description": "<p>Define the binding info required by the plugin.</p>",
    "group": "PluginDemo",
    "name": "getBindInfo",
    "permission": [
      {
        "name": "anyone"
      }
    ],
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "xcolumns",
            "description": "<p>Define the x columns.</p>"
          },
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "ycolumns",
            "description": "<p>Define the y columns.</p>"
          },
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "zcolumns",
            "description": "<p>Define the z columns.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Success-Response:",
          "content": "getBindInfo: () => {\n  return\n    {xcolumns:\n       [{\n          index: 0,\n          isDim: true\n       }],\n     ycolumns:\n      [{\n          index: 0,\n          isDim: false\n       }],\n     zcolumns:\n      [{\n          index: 0,\n          isDim: true\n       }]\n     };\n}",
          "type": "json"
        }
      ]
    },
    "version": "0.0.0",
    "filename": "plugin/PluginDemo.js",
    "groupTitle": "PluginDemo"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "getLocalView",
    "description": "<p>Get the local value. PluginName 是为了获取插件名称，不能缺失。</p>",
    "group": "PluginDemo",
    "name": "getLocalView",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "string",
            "optional": false,
            "field": "key",
            "description": "<p>Plug-in defined properties.</p>"
          }
        ]
      }
    },
    "permission": [
      {
        "name": "anyone"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Success-Response:",
          "content": "getLocalView: (key) => {\n   const LocalSetting = {\n      \"PluginName\": {\"zh_CN\": \"漏斗图\", \"en_US\": \"Funnel\", \"ja_JP\": \"漏斗图\", \"zh_TW\": \"漏斗图\"},\n      \"title\": {\"zh_CN\": \"标题\", \"en_US\": \"Title\", \"ja_JP\": \"タイトル\", \"zh_TW\": \"标题\"},\n      \"color\": {\"zh_CN\": \"颜色\", \"en_US\": \"Color\", \"ja_JP\": \"色彩\", \"zh_TW\": \"颜色\"},\n      \"font\": {\"zh_CN\": \"字体\", \"en_US\": \"Font\", \"ja_JP\": \"文字\", \"zh_TW\": \"字体\"},\n      \"line\": {\"zh_CN\": \"线\", \"en_US\": \"Line\", \"ja_JP\": \"线\", \"zh_TW\": \"线\"},\n      \"border\": {\"zh_CN\": \"边框\", \"en_US\": \"Border\", \"ja_JP\": \"边框\", \"zh_TW\": \"边框\"},\n      \"group1\": {\"zh_CN\": \"组1\", \"en_US\": \"group1\", \"ja_JP\": \"组1\", \"zh_TW\": \"组1\"},\n   }\n   return LocalSetting[key];\n}",
          "type": "json"
        }
      ]
    },
    "version": "0.0.0",
    "filename": "plugin/PluginDemo.js",
    "groupTitle": "PluginDemo"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "getProps",
    "description": "<p>Define the properties required by the plugin.</p>",
    "group": "PluginDemo",
    "name": "getProps",
    "permission": [
      {
        "name": "anyone"
      }
    ],
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "type",
            "description": "<p>Define the type of the property. Support: [&quot;number&quot;, &quot;string&quot;, &quot;color&quot;, &quot;line&quot;, &quot;integer&quot;, &quot;boolean&quot;, &quot;combo&quot;, &quot;font&quot;, &quot;param&quot;, &quot;chartColor&quot;, &quot;rotate&quot;, &quot;alpha&quot;, &quot;size&quot;]. Type &quot;combo&quot; property also need array options.</p>"
          },
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "key",
            "description": "<p>Define the key of the property.</p>"
          },
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "value",
            "description": "<p>Define the default value of the property.</p>"
          },
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "group",
            "description": "<p>Define the group value of the property. &quot;Multiple property as group properties&quot;</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Success-Response:",
          "content": "getProps: () => {\n   return\n    [{\n       type: 'number',\n       key: \"number1\",\n       value: 1.222\n    },\n     {\n       type: 'string',\n       key: \"title\",\n       value: \"标题\",\n       group: \"group1\"\n    },\n     {\n       type: 'color',\n       key: \"colorKey\",\n       value: 0xFF00FF\n    },\n     {\n       type: 'line',\n       key: \"linestyle\",\n       value: null\n    },\n     {\n       type: 'integer',\n       key: \"integerKey\",\n       value: 20,\n    },\n     {\n       type: 'boolean',\n       key: \"titleVisible\",\n       value: true (true, false)\n    },\n     {\n       type: 'combo',\n       key: \"titlePosition\",\n       value: \"标题位置\",\n       option: [\"top\", \"bottom\"],\n       group: \"group1\"\n    },\n     {\n       type: 'font',\n       key: \"fontKey\",\n       value: null\n    },\n     {\n       type: 'param',\n       key: \"param\",\n       value: (Param string, dashboard parameter, parameter element, or others)\n    },\n     {\n       type: 'chartColor',\n       key: \"chartColor\",\n       value: null\n    },\n     {\n       type: 'rotate',\n       key: \"xuanzhuan\",\n       value: 0 (0, 1, 2, 3, 4, 5, 6, 7, 8)\n    },\n     {\n       type: 'alpha',\n       key: \"alpha\",\n       value: 50 (0 - 100)\n    },\n     {\n       type: 'size',\n       key: \"fontSize\",\n       value: 12 (integer value)\n    }]\n}",
          "type": "json"
        }
      ]
    },
    "version": "0.0.0",
    "filename": "plugin/PluginDemo.js",
    "groupTitle": "PluginDemo"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "render",
    "description": "<p>Define the properties required by the plugin.</p>",
    "group": "PluginDemo",
    "name": "render",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "domName",
            "optional": false,
            "field": "domName",
            "description": "<p>Anchor node for rendering plugins.</p>"
          },
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "props",
            "description": "<p>Plugin properties.</p>"
          },
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "data",
            "description": "<p>Data define from the bind information.</p>"
          },
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "qinfo",
            "description": "<p>Qinfo define the bind columns information.</p>"
          }
        ]
      }
    },
    "permission": [
      {
        "name": "anyone"
      }
    ],
    "version": "0.0.0",
    "filename": "plugin/PluginDemo.js",
    "groupTitle": "PluginDemo"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "getRegistered",
    "description": "<p>Get the register plugin in the module.</p>",
    "group": "YHPluginManager",
    "name": "getRegistered",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "string",
            "optional": false,
            "field": "key",
            "description": "<p>Registration key</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "object",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin from module.</p>"
          }
        ]
      }
    },
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>Get registered plugin is null.</p>"
          }
        ]
      }
    },
    "version": "0.0.0",
    "filename": "plugin/npm/es/YHPluginManager.js",
    "groupTitle": "YHPluginManager"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "getRegistered",
    "description": "<p>Get the register plugin in the module.</p>",
    "group": "YHPluginManager",
    "name": "getRegistered",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "string",
            "optional": false,
            "field": "key",
            "description": "<p>Registration key</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "object",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin from module.</p>"
          }
        ]
      }
    },
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>Get registered plugin is null.</p>"
          }
        ]
      }
    },
    "version": "0.0.0",
    "filename": "plugin/npm/lib/YHPluginManager.js",
    "groupTitle": "YHPluginManager"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "isValid",
    "description": "<p>Check the plugin is valid or not.</p>",
    "group": "YHPluginManager",
    "name": "isValid",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "plugin",
            "description": "<p>Verified plugin</p>"
          }
        ]
      }
    },
    "permission": [
      {
        "name": "anyone"
      }
    ],
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>success.</p>"
          }
        ]
      }
    },
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "type": "array",
            "optional": false,
            "field": "warning",
            "description": "<p>The reason for the illegal plug-in.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Error-Response:",
          "content": "[\"No render method is defined.\"]",
          "type": "json"
        }
      ]
    },
    "version": "0.0.0",
    "filename": "plugin/npm/es/YHPluginManager.js",
    "groupTitle": "YHPluginManager"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "isValid",
    "description": "<p>Check the plugin is valid or not.</p>",
    "group": "YHPluginManager",
    "name": "isValid",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "plugin",
            "description": "<p>Verified plugin</p>"
          }
        ]
      }
    },
    "permission": [
      {
        "name": "anyone"
      }
    ],
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>success.</p>"
          }
        ]
      }
    },
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "type": "array",
            "optional": false,
            "field": "warning",
            "description": "<p>The reason for the illegal plug-in.</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "Error-Response:",
          "content": "[\"No render method is defined.\"]",
          "type": "json"
        }
      ]
    },
    "version": "0.0.0",
    "filename": "plugin/npm/lib/YHPluginManager.js",
    "groupTitle": "YHPluginManager"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "register",
    "description": "<p>Register plugin in the module.</p>",
    "group": "YHPluginManager",
    "name": "register",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "string",
            "optional": false,
            "field": "key",
            "description": "<p>Registration key</p>"
          },
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "plugin",
            "description": "<p>Registration plugin</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>success.</p>"
          }
        ]
      }
    },
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>Error message when registering.</p>"
          }
        ]
      }
    },
    "version": "0.0.0",
    "filename": "plugin/npm/es/YHPluginManager.js",
    "groupTitle": "YHPluginManager"
  },
  {
    "type": "GET",
    "url": "plugin",
    "title": "register",
    "description": "<p>Register plugin in the module.</p>",
    "group": "YHPluginManager",
    "name": "register",
    "parameter": {
      "fields": {
        "Parameter": [
          {
            "group": "Parameter",
            "type": "string",
            "optional": false,
            "field": "key",
            "description": "<p>Registration key</p>"
          },
          {
            "group": "Parameter",
            "type": "object",
            "optional": false,
            "field": "plugin",
            "description": "<p>Registration plugin</p>"
          }
        ]
      }
    },
    "success": {
      "fields": {
        "Success 200": [
          {
            "group": "Success 200",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>success.</p>"
          }
        ]
      }
    },
    "error": {
      "fields": {
        "Error 4xx": [
          {
            "group": "Error 4xx",
            "type": "string",
            "optional": false,
            "field": "result",
            "description": "<p>Error message when registering.</p>"
          }
        ]
      }
    },
    "version": "0.0.0",
    "filename": "plugin/npm/lib/YHPluginManager.js",
    "groupTitle": "YHPluginManager"
  }
] });
